.. Datamaestro Text documentation master file, created by
   sphinx-quickstart on Tue Oct 12 12:59:10 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Datamaestro Text's documentation!
============================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   api/index
   datasets/index


This `datamaestro <https://github.com/bpiwowar/datamaestro>`_ plugin covers text-related datasets:


* Information Retrieval
* Natural Language Processing tasks
* Recommendation


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
